@@ -96,7 +96,7 @@ class Oracle:
 
 
     def makePredictions(self,chr):
-        scores=[]
+        # scores=[]
         df_tmp = self.__loopList[self.__loopList['chr1']==chr]
         df_tmp = df_tmp.reset_index(drop=True)
         if df_tmp.shape[0]==0:
@@ -111,10 +111,11 @@ class Oracle:
             mat = mzd.getRecordsAsMatrix(x1,x2,y1,y2)
             batch[i,:self.__width-1,:self.__width-1,0] = self.preprocess(mat)
           prediction = self.__model.predict(batch)
-          df_tmp.loc[:,:]['score_oracle_' + str(reso)] = prediction.reshape(prediction.shape[0], )
-          scores.append(df_tmp)
+          df_tmp.loc[:,:]['score_oracle_' + str(reso)] = prediction#.reshape(prediction.shape[0], )
+          # scores.append(df_tmp)
         # print ('finished analyzing chromosome', chr, flush=True)
-        self.__oracleList.append(pd.concat(scores,ignore_index = True))
+        # self.__oracleList.append(pd.concat(scores,ignore_index = True))
+        self.__oracleList.append(df_tmp)
         return f'Finished analyzing {chr}'
 
 
